Module: Google::Apis::DeveloperconnectV1

Defined in:
lib/google/apis/developerconnect_v1.rb,
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/service.rb,
lib/google/apis/developerconnect_v1/gem_version.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Developer Connect API

Connect third-party source code management to Google

Defined Under Namespace

Classes: AccountConnector, AppHubService, AppHubWorkload, ArtifactConfig, ArtifactDeployment, BasicAuthentication, BearerTokenAuthentication, BitbucketCloudConfig, BitbucketDataCenterConfig, CancelOperationRequest, Connection, CryptoKeyConfig, CustomOAuthConfig, DeploymentEvent, DeveloperConnectService, Empty, ExchangeError, FetchAccessTokenRequest, FetchAccessTokenResponse, FetchGitHubInstallationsResponse, FetchGitRefsResponse, FetchLinkableGitRepositoriesResponse, FetchReadTokenRequest, FetchReadTokenResponse, FetchReadWriteTokenRequest, FetchReadWriteTokenResponse, FetchUserRepositoriesResponse, FinishOAuthResponse, GenericHttpEndpointConfig, GitHubConfig, GitHubEnterpriseConfig, GitLabConfig, GitLabEnterpriseConfig, GitProxyConfig, GitRepositoryLink, GkeWorkload, GoogleArtifactAnalysis, GoogleArtifactRegistry, GoogleCloudRun, HttpBody, InsightsConfig, Installation, InstallationState, LinkableGitRepository, ListAccountConnectorsResponse, ListConnectionsResponse, ListDeploymentEventsResponse, ListGitRepositoryLinksResponse, ListInsightsConfigsResponse, ListLocationsResponse, ListOperationsResponse, ListUsersResponse, Location, OAuthCredential, Operation, OperationMetadata, ProcessBitbucketCloudWebhookRequest, ProcessBitbucketDataCenterWebhookRequest, ProcessGitHubEnterpriseWebhookRequest, ProcessGitLabEnterpriseWebhookRequest, ProcessGitLabWebhookRequest, Projects, ProviderOAuthConfig, ProxyConfig, RuntimeConfig, SecureSourceManagerInstanceConfig, ServiceDirectoryConfig, StartOAuthResponse, Status, User, UserCredential, UserRepository

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-developerconnect_v1 gem

"0.24.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260403"
VERSION =

Version of the Developer Connect API this client connects to. This is NOT the gem version.

'V1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'