Class: Google::Apis::DeveloperconnectV1::BitbucketCloudConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::BitbucketCloudConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Configuration for connections to an instance of Bitbucket Cloud.
Instance Attribute Summary collapse
-
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.
-
#read_authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.
-
#webhook_secret_secret_version ⇒ String
Required.
-
#workspace ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BitbucketCloudConfig
constructor
A new instance of BitbucketCloudConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BitbucketCloudConfig
Returns a new instance of BitbucketCloudConfig.
344 345 346 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and
associated metadata.
Corresponds to the JSON property authorizerCredential
322 323 324 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 322 def @authorizer_credential end |
#read_authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and
associated metadata.
Corresponds to the JSON property readAuthorizerCredential
328 329 330 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 328 def @read_authorizer_credential end |
#webhook_secret_secret_version ⇒ String
Required. Immutable. SecretManager resource containing the webhook secret used
to verify webhook events, formatted as projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location). This is used to validate and create webhooks.
Corresponds to the JSON property webhookSecretSecretVersion
336 337 338 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 336 def webhook_secret_secret_version @webhook_secret_secret_version end |
#workspace ⇒ String
Required. The Bitbucket Cloud Workspace ID to be connected to Google Cloud
Platform.
Corresponds to the JSON property workspace
342 343 344 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 342 def workspace @workspace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
349 350 351 352 353 354 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 349 def update!(**args) @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential) @read_authorizer_credential = args[:read_authorizer_credential] if args.key?(:read_authorizer_credential) @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version) @workspace = args[:workspace] if args.key?(:workspace) end |