Class: Google::Apis::DeveloperconnectV1::BitbucketDataCenterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Configuration for connections to an instance of Bitbucket Data Center.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BitbucketDataCenterConfig

Returns a new instance of BitbucketDataCenterConfig.



412
413
414
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizer_credentialGoogle::Apis::DeveloperconnectV1::UserCredential

Represents a personal access token that authorized the Connection, and associated metadata. Corresponds to the JSON property authorizerCredential



373
374
375
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 373

def authorizer_credential
  @authorizer_credential
end

#host_uriString

Required. The URI of the Bitbucket Data Center host this connection is for. Corresponds to the JSON property hostUri

Returns:

  • (String)


378
379
380
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 378

def host_uri
  @host_uri
end

#read_authorizer_credentialGoogle::Apis::DeveloperconnectV1::UserCredential

Represents a personal access token that authorized the Connection, and associated metadata. Corresponds to the JSON property readAuthorizerCredential



384
385
386
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 384

def read_authorizer_credential
  @read_authorizer_credential
end

#server_versionString

Output only. Version of the Bitbucket Data Center server running on the host_uri. Corresponds to the JSON property serverVersion

Returns:

  • (String)


390
391
392
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 390

def server_version
  @server_version
end

#service_directory_configGoogle::Apis::DeveloperconnectV1::ServiceDirectoryConfig

ServiceDirectoryConfig represents Service Directory configuration for a connection. Corresponds to the JSON property serviceDirectoryConfig



396
397
398
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 396

def service_directory_config
  @service_directory_config
end

#ssl_ca_certificateString

Optional. SSL certificate authority to trust when making requests to Bitbucket Data Center. Corresponds to the JSON property sslCaCertificate

Returns:

  • (String)


402
403
404
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 402

def ssl_ca_certificate
  @ssl_ca_certificate
end

#webhook_secret_secret_versionString

Required. Immutable. SecretManager resource containing the webhook secret used to verify webhook events, formatted as projects/*/secrets/*/versions/* or projects/*/locations/*/secrets/*/versions/* (if regional secrets are supported in that location). This is used to validate webhooks. Corresponds to the JSON property webhookSecretSecretVersion

Returns:

  • (String)


410
411
412
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 410

def webhook_secret_secret_version
  @webhook_secret_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



417
418
419
420
421
422
423
424
425
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 417

def update!(**args)
  @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential)
  @host_uri = args[:host_uri] if args.key?(:host_uri)
  @read_authorizer_credential = args[:read_authorizer_credential] if args.key?(:read_authorizer_credential)
  @server_version = args[:server_version] if args.key?(:server_version)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate)
  @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version)
end