Class: Google::Apis::DeveloperconnectV1::Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Message describing Connection object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Connection

Returns a new instance of Connection.



560
561
562
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Allows clients to store small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


448
449
450
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 448

def annotations
  @annotations
end

#bitbucket_cloud_configGoogle::Apis::DeveloperconnectV1::BitbucketCloudConfig

Configuration for connections to an instance of Bitbucket Cloud. Corresponds to the JSON property bitbucketCloudConfig



453
454
455
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 453

def bitbucket_cloud_config
  @bitbucket_cloud_config
end

#bitbucket_data_center_configGoogle::Apis::DeveloperconnectV1::BitbucketDataCenterConfig

Configuration for connections to an instance of Bitbucket Data Center. Corresponds to the JSON property bitbucketDataCenterConfig



458
459
460
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 458

def bitbucket_data_center_config
  @bitbucket_data_center_config
end

#create_timeString

Output only. [Output only] Create timestamp Corresponds to the JSON property createTime

Returns:

  • (String)


463
464
465
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 463

def create_time
  @create_time
end

#crypto_key_configGoogle::Apis::DeveloperconnectV1::CryptoKeyConfig

The crypto key configuration. This field is used by the Customer-managed encryption keys (CMEK) feature. Corresponds to the JSON property cryptoKeyConfig



469
470
471
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 469

def crypto_key_config
  @crypto_key_config
end

#delete_timeString

Output only. [Output only] Delete timestamp Corresponds to the JSON property deleteTime

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 474

def delete_time
  @delete_time
end

#disabledBoolean Also known as: disabled?

Optional. If disabled is set to true, functionality is disabled for this connection. Repository based API methods and webhooks processing for repositories in this connection will be disabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


481
482
483
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 481

def disabled
  @disabled
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


489
490
491
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 489

def etag
  @etag
end

#git_proxy_configGoogle::Apis::DeveloperconnectV1::GitProxyConfig

The git proxy configuration. Corresponds to the JSON property gitProxyConfig



494
495
496
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 494

def git_proxy_config
  @git_proxy_config
end

#github_configGoogle::Apis::DeveloperconnectV1::GitHubConfig

Configuration for connections to github.com. Corresponds to the JSON property githubConfig



499
500
501
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 499

def github_config
  @github_config
end

#github_enterprise_configGoogle::Apis::DeveloperconnectV1::GitHubEnterpriseConfig

Configuration for connections to an instance of GitHub Enterprise. Corresponds to the JSON property githubEnterpriseConfig



504
505
506
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 504

def github_enterprise_config
  @github_enterprise_config
end

#gitlab_configGoogle::Apis::DeveloperconnectV1::GitLabConfig

Configuration for connections to gitlab.com. Corresponds to the JSON property gitlabConfig



509
510
511
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 509

def gitlab_config
  @gitlab_config
end

#gitlab_enterprise_configGoogle::Apis::DeveloperconnectV1::GitLabEnterpriseConfig

Configuration for connections to an instance of GitLab Enterprise. Corresponds to the JSON property gitlabEnterpriseConfig



514
515
516
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 514

def gitlab_enterprise_config
  @gitlab_enterprise_config
end

#http_configGoogle::Apis::DeveloperconnectV1::GenericHttpEndpointConfig

Defines the configuration for connections to an HTTP service provider. Corresponds to the JSON property httpConfig



519
520
521
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 519

def http_config
  @http_config
end

#installation_stateGoogle::Apis::DeveloperconnectV1::InstallationState

Describes stage and necessary actions to be taken by the user to complete the installation. Used for GitHub and GitHub Enterprise based connections. Corresponds to the JSON property installationState



525
526
527
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 525

def installation_state
  @installation_state
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


530
531
532
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 530

def labels
  @labels
end

#nameString

Identifier. The resource name of the connection, in the format projects/ project/locations/location/connections/connection_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


536
537
538
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 536

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. Set to true when the connection is being set up or updated in the background. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


542
543
544
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 542

def reconciling
  @reconciling
end

#secure_source_manager_instance_configGoogle::Apis::DeveloperconnectV1::SecureSourceManagerInstanceConfig

Configuration for connections to Secure Source Manager instance Corresponds to the JSON property secureSourceManagerInstanceConfig



548
549
550
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 548

def secure_source_manager_instance_config
  @secure_source_manager_instance_config
end

#uidString

Output only. A system-assigned unique identifier for the Connection. Corresponds to the JSON property uid

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 553

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update timestamp Corresponds to the JSON property updateTime

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 558

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 565

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @bitbucket_cloud_config = args[:bitbucket_cloud_config] if args.key?(:bitbucket_cloud_config)
  @bitbucket_data_center_config = args[:bitbucket_data_center_config] if args.key?(:bitbucket_data_center_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_config = args[:crypto_key_config] if args.key?(:crypto_key_config)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @disabled = args[:disabled] if args.key?(:disabled)
  @etag = args[:etag] if args.key?(:etag)
  @git_proxy_config = args[:git_proxy_config] if args.key?(:git_proxy_config)
  @github_config = args[:github_config] if args.key?(:github_config)
  @github_enterprise_config = args[:github_enterprise_config] if args.key?(:github_enterprise_config)
  @gitlab_config = args[:gitlab_config] if args.key?(:gitlab_config)
  @gitlab_enterprise_config = args[:gitlab_enterprise_config] if args.key?(:gitlab_enterprise_config)
  @http_config = args[:http_config] if args.key?(:http_config)
  @installation_state = args[:installation_state] if args.key?(:installation_state)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @secure_source_manager_instance_config = args[:secure_source_manager_instance_config] if args.key?(:secure_source_manager_instance_config)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end