Class: Google::Apis::DeveloperconnectV1::FetchLinkableGitRepositoriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Response message for FetchLinkableGitRepositories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchLinkableGitRepositoriesResponse

Returns a new instance of FetchLinkableGitRepositoriesResponse.



916
917
918
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#linkable_git_repositoriesArray<Google::Apis::DeveloperconnectV1::LinkableGitRepository>

The git repositories that can be linked to the connection. Corresponds to the JSON property linkableGitRepositories



909
910
911
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 909

def linkable_git_repositories
  @linkable_git_repositories
end

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


914
915
916
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 914

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



921
922
923
924
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 921

def update!(**args)
  @linkable_git_repositories = args[:linkable_git_repositories] if args.key?(:linkable_git_repositories)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end