Class: Google::Apis::DeveloperconnectV1::FetchReadTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::FetchReadTokenResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Message for responding to get read token.
Instance Attribute Summary collapse
-
#expiration_time ⇒ String
Expiration timestamp.
-
#git_username ⇒ String
The git_username to specify when making a git clone with the token.
-
#token ⇒ String
The token content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchReadTokenResponse
constructor
A new instance of FetchReadTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchReadTokenResponse
Returns a new instance of FetchReadTokenResponse.
960 961 962 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_time ⇒ String
Expiration timestamp. Can be empty if unknown or non-expiring.
Corresponds to the JSON property expirationTime
947 948 949 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 947 def expiration_time @expiration_time end |
#git_username ⇒ String
The git_username to specify when making a git clone with the token. For
example, for GitHub GitRepositoryLinks, this would be "x-access-token"
Corresponds to the JSON property gitUsername
953 954 955 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 953 def git_username @git_username end |
#token ⇒ String
The token content.
Corresponds to the JSON property token
958 959 960 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 958 def token @token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
965 966 967 968 969 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 965 def update!(**args) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @git_username = args[:git_username] if args.key?(:git_username) @token = args[:token] if args.key?(:token) end |