Class: Google::Apis::DeveloperconnectV1::FetchUserRepositoriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Response message for FetchUserRepositories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchUserRepositoriesResponse

Returns a new instance of FetchUserRepositoriesResponse.



1031
1032
1033
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1024

def next_page_token
  @next_page_token
end

#user_reposArray<Google::Apis::DeveloperconnectV1::UserRepository>

The repositories that the user can access with this account connector. Corresponds to the JSON property userRepos



1029
1030
1031
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1029

def user_repos
  @user_repos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1036
1037
1038
1039
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1036

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @user_repos = args[:user_repos] if args.key?(:user_repos)
end