Class: Google::Apis::DeveloperconnectV1::GitHubConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::GitHubConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Configuration for connections to github.com.
Instance Attribute Summary collapse
-
#app_installation_id ⇒ Fixnum
Optional.
-
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::OAuthCredential
Represents an OAuth token of the account that authorized the Connection, and associated metadata.
-
#github_app ⇒ String
Required.
-
#installation_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitHubConfig
constructor
A new instance of GitHubConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitHubConfig
Returns a new instance of GitHubConfig.
1160 1161 1162 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_installation_id ⇒ Fixnum
Optional. GitHub App installation id.
Corresponds to the JSON property appInstallationId
1140 1141 1142 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1140 def app_installation_id @app_installation_id end |
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::OAuthCredential
Represents an OAuth token of the account that authorized the Connection, and
associated metadata.
Corresponds to the JSON property authorizerCredential
1146 1147 1148 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1146 def @authorizer_credential end |
#github_app ⇒ String
Required. Immutable. The GitHub Application that was installed to the GitHub
user or organization.
Corresponds to the JSON property githubApp
1152 1153 1154 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1152 def github_app @github_app end |
#installation_uri ⇒ String
Output only. The URI to navigate to in order to manage the installation
associated with this GitHubConfig.
Corresponds to the JSON property installationUri
1158 1159 1160 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1158 def installation_uri @installation_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1165 1166 1167 1168 1169 1170 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1165 def update!(**args) @app_installation_id = args[:app_installation_id] if args.key?(:app_installation_id) @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential) @github_app = args[:github_app] if args.key?(:github_app) @installation_uri = args[:installation_uri] if args.key?(:installation_uri) end |