Class: Google::Apis::DeveloperconnectV1::GitHubEnterpriseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Configuration for connections to an instance of GitHub Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitHubEnterpriseConfig

Returns a new instance of GitHubEnterpriseConfig.



1247
1248
1249
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idFixnum

Optional. ID of the GitHub App created from the manifest. Corresponds to the JSON property appId

Returns:

  • (Fixnum)


1188
1189
1190
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1188

def app_id
  @app_id
end

#app_installation_idFixnum

Optional. ID of the installation of the GitHub App. Corresponds to the JSON property appInstallationId

Returns:

  • (Fixnum)


1193
1194
1195
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1193

def app_installation_id
  @app_installation_id
end

#app_slugString

Output only. The URL-friendly name of the GitHub App. Corresponds to the JSON property appSlug

Returns:

  • (String)


1198
1199
1200
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1198

def app_slug
  @app_slug
end

#host_uriString

Required. The URI of the GitHub Enterprise host this connection is for. Corresponds to the JSON property hostUri

Returns:

  • (String)


1203
1204
1205
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1203

def host_uri
  @host_uri
end

#installation_uriString

Output only. The URI to navigate to in order to manage the installation associated with this GitHubEnterpriseConfig. Corresponds to the JSON property installationUri

Returns:

  • (String)


1209
1210
1211
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1209

def installation_uri
  @installation_uri
end

#organizationString

Optional. Immutable. GitHub Enterprise organization in which the GitHub App is created. Corresponds to the JSON property organization

Returns:

  • (String)


1215
1216
1217
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1215

def organization
  @organization
end

#private_key_secret_versionString

Optional. SecretManager resource containing the private key of the GitHub App, formatted as projects/*/secrets/*/versions/* or projects/*/locations/*/ secrets/*/versions/* (if regional secrets are supported in that location). Corresponds to the JSON property privateKeySecretVersion

Returns:

  • (String)


1222
1223
1224
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1222

def private_key_secret_version
  @private_key_secret_version
end

#server_versionString

Output only. GitHub Enterprise version installed at the host_uri. Corresponds to the JSON property serverVersion

Returns:

  • (String)


1227
1228
1229
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1227

def server_version
  @server_version
end

#service_directory_configGoogle::Apis::DeveloperconnectV1::ServiceDirectoryConfig

ServiceDirectoryConfig represents Service Directory configuration for a connection. Corresponds to the JSON property serviceDirectoryConfig



1233
1234
1235
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1233

def service_directory_config
  @service_directory_config
end

#ssl_ca_certificateString

Optional. SSL certificate to use for requests to GitHub Enterprise. Corresponds to the JSON property sslCaCertificate

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1238

def ssl_ca_certificate
  @ssl_ca_certificate
end

#webhook_secret_secret_versionString

Optional. SecretManager resource containing the webhook secret of the GitHub App, formatted as projects/*/secrets/*/versions/* or projects/*/locations/*/ secrets/*/versions/* (if regional secrets are supported in that location). Corresponds to the JSON property webhookSecretSecretVersion

Returns:

  • (String)


1245
1246
1247
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1245

def webhook_secret_secret_version
  @webhook_secret_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1252

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_installation_id = args[:app_installation_id] if args.key?(:app_installation_id)
  @app_slug = args[:app_slug] if args.key?(:app_slug)
  @host_uri = args[:host_uri] if args.key?(:host_uri)
  @installation_uri = args[:installation_uri] if args.key?(:installation_uri)
  @organization = args[:organization] if args.key?(:organization)
  @private_key_secret_version = args[:private_key_secret_version] if args.key?(:private_key_secret_version)
  @server_version = args[:server_version] if args.key?(:server_version)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate)
  @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version)
end