Class: Google::Apis::DeveloperconnectV1::GitLabEnterpriseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Configuration for connections to an instance of GitLab Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitLabEnterpriseConfig

Returns a new instance of GitLabEnterpriseConfig.



1341
1342
1343
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizer_credentialGoogle::Apis::DeveloperconnectV1::UserCredential

Represents a personal access token that authorized the Connection, and associated metadata. Corresponds to the JSON property authorizerCredential



1303
1304
1305
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1303

def authorizer_credential
  @authorizer_credential
end

#host_uriString

Required. The URI of the GitLab Enterprise host this connection is for. Corresponds to the JSON property hostUri

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1308

def host_uri
  @host_uri
end

#read_authorizer_credentialGoogle::Apis::DeveloperconnectV1::UserCredential

Represents a personal access token that authorized the Connection, and associated metadata. Corresponds to the JSON property readAuthorizerCredential



1314
1315
1316
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1314

def read_authorizer_credential
  @read_authorizer_credential
end

#server_versionString

Output only. Version of the GitLab Enterprise server running on the host_uri. Corresponds to the JSON property serverVersion

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1319

def server_version
  @server_version
end

#service_directory_configGoogle::Apis::DeveloperconnectV1::ServiceDirectoryConfig

ServiceDirectoryConfig represents Service Directory configuration for a connection. Corresponds to the JSON property serviceDirectoryConfig



1325
1326
1327
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1325

def service_directory_config
  @service_directory_config
end

#ssl_ca_certificateString

Optional. SSL Certificate Authority certificate to use for requests to GitLab Enterprise instance. Corresponds to the JSON property sslCaCertificate

Returns:

  • (String)


1331
1332
1333
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1331

def ssl_ca_certificate
  @ssl_ca_certificate
end

#webhook_secret_secret_versionString

Required. Immutable. SecretManager resource containing the webhook secret of a GitLab project, formatted as projects/*/secrets/*/versions/* or projects/*/ locations/*/secrets/*/versions/* (if regional secrets are supported in that location). This is used to validate webhooks. Corresponds to the JSON property webhookSecretSecretVersion

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1339

def webhook_secret_secret_version
  @webhook_secret_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1346

def update!(**args)
  @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential)
  @host_uri = args[:host_uri] if args.key?(:host_uri)
  @read_authorizer_credential = args[:read_authorizer_credential] if args.key?(:read_authorizer_credential)
  @server_version = args[:server_version] if args.key?(:server_version)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate)
  @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version)
end