Class: Google::Apis::DeveloperconnectV1::GitRepositoryLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Message describing the GitRepositoryLink object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitRepositoryLink

Returns a new instance of GitRepositoryLink.



1465
1466
1467
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Allows clients to store small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1402
1403
1404
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1402

def annotations
  @annotations
end

#clone_uriString

Required. Git Clone URI. Corresponds to the JSON property cloneUri

Returns:

  • (String)


1407
1408
1409
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1407

def clone_uri
  @clone_uri
end

#create_timeString

Output only. [Output only] Create timestamp Corresponds to the JSON property createTime

Returns:

  • (String)


1412
1413
1414
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1412

def create_time
  @create_time
end

#delete_timeString

Output only. [Output only] Delete timestamp Corresponds to the JSON property deleteTime

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1417

def delete_time
  @delete_time
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1424
1425
1426
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1424

def etag
  @etag
end

#git_proxy_uriString

Output only. URI to access the linked repository through the Git Proxy. This field is only populated if the git proxy is enabled for the connection. Corresponds to the JSON property gitProxyUri

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1430

def git_proxy_uri
  @git_proxy_uri
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1435
1436
1437
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1435

def labels
  @labels
end

#nameString

Identifier. Resource name of the repository, in the format projects/*/ locations/*/connections/*/gitRepositoryLinks/*. Corresponds to the JSON property name

Returns:

  • (String)


1441
1442
1443
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1441

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. Set to true when the connection is being set up or updated in the background. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1447
1448
1449
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1447

def reconciling
  @reconciling
end

#uidString

Output only. A system-assigned unique identifier for the GitRepositoryLink. Corresponds to the JSON property uid

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1453

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update timestamp Corresponds to the JSON property updateTime

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1458

def update_time
  @update_time
end

#webhook_idString

Output only. External ID of the webhook created for the repository. Corresponds to the JSON property webhookId

Returns:

  • (String)


1463
1464
1465
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1463

def webhook_id
  @webhook_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1470

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @clone_uri = args[:clone_uri] if args.key?(:clone_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @etag = args[:etag] if args.key?(:etag)
  @git_proxy_uri = args[:git_proxy_uri] if args.key?(:git_proxy_uri)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @webhook_id = args[:webhook_id] if args.key?(:webhook_id)
end