Class: Google::Apis::DeveloperconnectV1::InsightsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

The InsightsConfig resource is the core configuration object to capture events from your Software Development Lifecycle. It acts as the central hub for managing how Developer Connect understands your application, its runtime environments, and the artifacts deployed within them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsightsConfig

Returns a new instance of InsightsConfig.



1676
1677
1678
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. User specified annotations. See https://google.aip.dev/148# annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1609
1610
1611
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1609

def annotations
  @annotations
end

#app_hub_applicationString

Optional. The name of the App Hub Application. Format: projects/project/ locations/location/applications/application Corresponds to the JSON property appHubApplication

Returns:

  • (String)


1615
1616
1617
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1615

def app_hub_application
  @app_hub_application
end

#artifact_configsArray<Google::Apis::DeveloperconnectV1::ArtifactConfig>

Optional. The artifact configurations of the artifacts that are deployed. Corresponds to the JSON property artifactConfigs



1620
1621
1622
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1620

def artifact_configs
  @artifact_configs
end

#create_timeString

Output only. Create timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1625
1626
1627
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1625

def create_time
  @create_time
end

#errorsArray<Google::Apis::DeveloperconnectV1::Status>

Output only. Any errors that occurred while setting up the InsightsConfig. Each error will be in the format: field_name: error_message, e.g. GetAppHubApplication: Permission denied while getting App Hub application. Please grant permissions to the P4SA. Corresponds to the JSON property errors



1633
1634
1635
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1633

def errors
  @errors
end

#labelsHash<String,String>

Optional. Set of labels associated with an InsightsConfig. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1638
1639
1640
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1638

def labels
  @labels
end

#nameString

Identifier. The name of the InsightsConfig. Format: projects/project/ locations/location/insightsConfigs/insightsConfig Corresponds to the JSON property name

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1644

def name
  @name
end

#projectsGoogle::Apis::DeveloperconnectV1::Projects

Projects represents the projects to track with the InsightsConfig. Corresponds to the JSON property projects



1649
1650
1651
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1649

def projects
  @projects
end

#reconcilingBoolean Also known as: reconciling?

Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to true if the current state of InsightsConfig does not match the user's intended state, and the service is actively updating the resource to reconcile them. This can happen due to user-triggered updates or system actions like failover or maintenance. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1658
1659
1660
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1658

def reconciling
  @reconciling
end

#runtime_configsArray<Google::Apis::DeveloperconnectV1::RuntimeConfig>

Output only. The runtime configurations where the application is deployed. Corresponds to the JSON property runtimeConfigs



1664
1665
1666
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1664

def runtime_configs
  @runtime_configs
end

#stateString

Optional. Output only. The state of the InsightsConfig. Corresponds to the JSON property state

Returns:

  • (String)


1669
1670
1671
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1669

def state
  @state
end

#update_timeString

Output only. Update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1674
1675
1676
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1674

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1681

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_hub_application = args[:app_hub_application] if args.key?(:app_hub_application)
  @artifact_configs = args[:artifact_configs] if args.key?(:artifact_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @errors = args[:errors] if args.key?(:errors)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @projects = args[:projects] if args.key?(:projects)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @runtime_configs = args[:runtime_configs] if args.key?(:runtime_configs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end