Class: Google::Apis::DeveloperconnectV1::InstallationState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Describes stage and necessary actions to be taken by the user to complete the installation. Used for GitHub and GitHub Enterprise based connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstallationState

Returns a new instance of InstallationState.



1750
1751
1752
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_uriString

Output only. Link to follow for next action. Empty string if the installation is already complete. Corresponds to the JSON property actionUri

Returns:

  • (String)


1737
1738
1739
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1737

def action_uri
  @action_uri
end

#messageString

Output only. Message of what the user should do next to continue the installation. Empty string if the installation is already complete. Corresponds to the JSON property message

Returns:

  • (String)


1743
1744
1745
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1743

def message
  @message
end

#stageString

Output only. Current step of the installation process. Corresponds to the JSON property stage

Returns:

  • (String)


1748
1749
1750
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1748

def stage
  @stage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1755
1756
1757
1758
1759
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1755

def update!(**args)
  @action_uri = args[:action_uri] if args.key?(:action_uri)
  @message = args[:message] if args.key?(:message)
  @stage = args[:stage] if args.key?(:stage)
end