Class: Google::Apis::DeveloperconnectV1::ListGitRepositoryLinksResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::ListGitRepositoryLinksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Message for response to listing GitRepositoryLinks
Instance Attribute Summary collapse
-
#git_repository_links ⇒ Array<Google::Apis::DeveloperconnectV1::GitRepositoryLink>
The list of GitRepositoryLinks Corresponds to the JSON property
gitRepositoryLinks. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGitRepositoryLinksResponse
constructor
A new instance of ListGitRepositoryLinksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGitRepositoryLinksResponse
Returns a new instance of ListGitRepositoryLinksResponse.
1889 1890 1891 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#git_repository_links ⇒ Array<Google::Apis::DeveloperconnectV1::GitRepositoryLink>
The list of GitRepositoryLinks
Corresponds to the JSON property gitRepositoryLinks
1877 1878 1879 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1877 def git_repository_links @git_repository_links end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1882 1883 1884 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1882 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1887 1888 1889 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1887 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1894 1895 1896 1897 1898 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1894 def update!(**args) @git_repository_links = args[:git_repository_links] if args.key?(:git_repository_links) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |