Class: Google::Apis::DeveloperconnectV1::ListInsightsConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::ListInsightsConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Request for response to listing InsightsConfigs.
Instance Attribute Summary collapse
-
#insights_configs ⇒ Array<Google::Apis::DeveloperconnectV1::InsightsConfig>
The list of InsightsConfigs.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInsightsConfigsResponse
constructor
A new instance of ListInsightsConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInsightsConfigsResponse
Returns a new instance of ListInsightsConfigsResponse.
1912 1913 1914 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insights_configs ⇒ Array<Google::Apis::DeveloperconnectV1::InsightsConfig>
The list of InsightsConfigs.
Corresponds to the JSON property insightsConfigs
1900 1901 1902 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1900 def insights_configs @insights_configs end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1905 1906 1907 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1905 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1910 1911 1912 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1910 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1917 1918 1919 1920 1921 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1917 def update!(**args) @insights_configs = args[:insights_configs] if args.key?(:insights_configs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |