Class: Google::Apis::DeveloperconnectV1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::DeveloperconnectV1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
1971 1972 1973 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1956 1957 1958 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1956 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::DeveloperconnectV1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1961 1962 1963 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1961 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
1969 1970 1971 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1969 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1976 1977 1978 1979 1980 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1976 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |