Class: Google::Apis::DeveloperconnectV1::ProcessBitbucketCloudWebhookRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

RPC request object accepted by the ProcessBitbucketCloudWebhook RPC method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProcessBitbucketCloudWebhookRequest

Returns a new instance of ProcessBitbucketCloudWebhookRequest.



2243
2244
2245
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bodyGoogle::Apis::DeveloperconnectV1::HttpBody

Message that represents an arbitrary HTTP body. It should only be used for payload formats that can't be represented as JSON, such as raw binary or an HTML page. This message can be used both in streaming and non-streaming API methods in the request as well as the response. It can be used as a top-level request field, which is convenient if one wants to extract parameters from either the URL or HTTP template into the request fields and also want access to the raw HTTP body. Example: message GetResourceRequest // A unique request id. string request_id = 1; // The raw HTTP body is bound to this field. google.api.HttpBody http_body = 2; service ResourceService rpc GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); Example with streaming methods: service CaldavService rpc GetCalendar(stream google. api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream google.api.HttpBody) returns (stream google.api.HttpBody); Use of this type only changes how the request and response bodies are handled, all other features will continue to work unchanged. Corresponds to the JSON property body



2241
2242
2243
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2241

def body
  @body
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2248
2249
2250
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2248

def update!(**args)
  @body = args[:body] if args.key?(:body)
end