Class: Google::Apis::DeveloperconnectV1::ProcessBitbucketDataCenterWebhookRequest
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::ProcessBitbucketDataCenterWebhookRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
RPC request object accepted by the ProcessBitbucketDataCenterWebhook RPC method.
Instance Attribute Summary collapse
-
#body ⇒ Google::Apis::DeveloperconnectV1::HttpBody
Message that represents an arbitrary HTTP body.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProcessBitbucketDataCenterWebhookRequest
constructor
A new instance of ProcessBitbucketDataCenterWebhookRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProcessBitbucketDataCenterWebhookRequest
Returns a new instance of ProcessBitbucketDataCenterWebhookRequest.
2270 2271 2272 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ Google::Apis::DeveloperconnectV1::HttpBody
Message that represents an arbitrary HTTP body. It should only be used for
payload formats that can't be represented as JSON, such as raw binary or an
HTML page. This message can be used both in streaming and non-streaming API
methods in the request as well as the response. It can be used as a top-level
request field, which is convenient if one wants to extract parameters from
either the URL or HTTP template into the request fields and also want access
to the raw HTTP body. Example: message GetResourceRequest // A unique
request id. string request_id = 1; // The raw HTTP body is bound to this field.
google.api.HttpBody http_body = 2; service ResourceService rpc
GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc
UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); Example
with streaming methods: service CaldavService rpc GetCalendar(stream google.
api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream
google.api.HttpBody) returns (stream google.api.HttpBody); Use of this type
only changes how the request and response bodies are handled, all other
features will continue to work unchanged.
Corresponds to the JSON property body
2268 2269 2270 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2268 def body @body end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2275 2276 2277 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2275 def update!(**args) @body = args[:body] if args.key?(:body) end |