Class: Google::Apis::DeveloperconnectV1::ProviderOAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

ProviderOAuthConfig is the OAuth config for a provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProviderOAuthConfig

Returns a new instance of ProviderOAuthConfig.



2425
2426
2427
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scopesArray<String>

Required. User selected scopes to apply to the Oauth config In the event of changing scopes, user records under AccountConnector will be deleted and users will re-auth again. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


2418
2419
2420
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2418

def scopes
  @scopes
end

#system_provider_idString

Optional. Immutable. Developer Connect provided OAuth. Corresponds to the JSON property systemProviderId

Returns:

  • (String)


2423
2424
2425
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2423

def system_provider_id
  @system_provider_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2430
2431
2432
2433
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2430

def update!(**args)
  @scopes = args[:scopes] if args.key?(:scopes)
  @system_provider_id = args[:system_provider_id] if args.key?(:system_provider_id)
end