Class: Google::Apis::DeveloperconnectV1::ProxyConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::ProxyConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
The proxy configuration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#http_proxy_base_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProxyConfig
constructor
A new instance of ProxyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProxyConfig
Returns a new instance of ProxyConfig.
2455 2456 2457 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Setting this to true allows the git and http proxies to perform
actions on behalf of the user configured under the account connector.
Corresponds to the JSON property enabled
2444 2445 2446 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2444 def enabled @enabled end |
#http_proxy_base_uri ⇒ String
Output only. The base URI for the HTTP proxy endpoint. Has the format https://
generatedID-a-h-shortRegion.developerconnect.dev Populated only when
enabled is set to true. This endpoint is used by other Google services that
integrate with Developer Connect.
Corresponds to the JSON property httpProxyBaseUri
2453 2454 2455 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2453 def http_proxy_base_uri @http_proxy_base_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2460 2461 2462 2463 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2460 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @http_proxy_base_uri = args[:http_proxy_base_uri] if args.key?(:http_proxy_base_uri) end |