Class: Google::Apis::DeveloperconnectV1::UserCredential

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Represents a personal access token that authorized the Connection, and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserCredential

Returns a new instance of UserCredential.



2702
2703
2704
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#user_token_secret_versionString

Required. A SecretManager resource containing the user token that authorizes the Developer Connect connection. Format: projects/*/secrets/*/versions/* or projects/*/locations/*/secrets/*/versions/* (if regional secrets are supported in that location). Corresponds to the JSON property userTokenSecretVersion

Returns:

  • (String)


2695
2696
2697
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2695

def user_token_secret_version
  @user_token_secret_version
end

#usernameString

Output only. The username associated with this token. Corresponds to the JSON property username

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2700

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2707
2708
2709
2710
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2707

def update!(**args)
  @user_token_secret_version = args[:user_token_secret_version] if args.key?(:user_token_secret_version)
  @username = args[:username] if args.key?(:username)
end