Class: Google::Apis::DeveloperconnectV1::AccountConnector
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::AccountConnector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
AccountConnector encapsulates what a platform administrator needs to configure for users to connect to the service providers, which includes, among other fields, the OAuth client ID, client secret, and authorization and token endpoints.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#custom_oauth_config ⇒ Google::Apis::DeveloperconnectV1::CustomOAuthConfig
Message for a customized OAuth config.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#oauth_start_uri ⇒ String
Output only.
-
#provider_oauth_config ⇒ Google::Apis::DeveloperconnectV1::ProviderOAuthConfig
ProviderOAuthConfig is the OAuth config for a provider.
-
#proxy_config ⇒ Google::Apis::DeveloperconnectV1::ProxyConfig
The proxy configuration.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccountConnector
constructor
A new instance of AccountConnector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AccountConnector
Returns a new instance of AccountConnector.
90 91 92 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 90 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Allows users to store small amounts of arbitrary data.
Corresponds to the JSON property annotations
35 36 37 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 35 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the accountConnector was created.
Corresponds to the JSON property createTime
40 41 42 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 40 def create_time @create_time end |
#custom_oauth_config ⇒ Google::Apis::DeveloperconnectV1::CustomOAuthConfig
Message for a customized OAuth config.
Corresponds to the JSON property customOauthConfig
45 46 47 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 45 def custom_oauth_config @custom_oauth_config end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding.
Corresponds to the JSON property etag
52 53 54 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 52 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
57 58 59 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 57 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the accountConnector, in the format projects/
project/locations/location/accountConnectors/account_connector_id`.
Corresponds to the JSON propertyname`
63 64 65 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 63 def name @name end |
#oauth_start_uri ⇒ String
Output only. Start OAuth flow by clicking on this URL.
Corresponds to the JSON property oauthStartUri
68 69 70 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 68 def oauth_start_uri @oauth_start_uri end |
#provider_oauth_config ⇒ Google::Apis::DeveloperconnectV1::ProviderOAuthConfig
ProviderOAuthConfig is the OAuth config for a provider.
Corresponds to the JSON property providerOauthConfig
73 74 75 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 73 def provider_oauth_config @provider_oauth_config end |
#proxy_config ⇒ Google::Apis::DeveloperconnectV1::ProxyConfig
The proxy configuration.
Corresponds to the JSON property proxyConfig
78 79 80 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 78 def proxy_config @proxy_config end |
#uid ⇒ String
Output only. A system-assigned unique identifier for the Account Connector.
Corresponds to the JSON property uid
83 84 85 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 83 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the accountConnector was updated.
Corresponds to the JSON property updateTime
88 89 90 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 88 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 95 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @custom_oauth_config = args[:custom_oauth_config] if args.key?(:custom_oauth_config) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @oauth_start_uri = args[:oauth_start_uri] if args.key?(:oauth_start_uri) @provider_oauth_config = args[:provider_oauth_config] if args.key?(:provider_oauth_config) @proxy_config = args[:proxy_config] if args.key?(:proxy_config) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |