Class: Google::Apis::DeveloperconnectV1::ArtifactDeployment
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::ArtifactDeployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
The ArtifactDeployment resource represents the deployment of the artifact within the InsightsConfig resource.
Instance Attribute Summary collapse
-
#artifact_alias ⇒ String
Output only.
-
#artifact_reference ⇒ String
Output only.
-
#container_status_summary ⇒ String
Output only.
-
#deploy_time ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#source_commit_uris ⇒ Array<String>
Output only.
-
#undeploy_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ArtifactDeployment
constructor
A new instance of ArtifactDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ArtifactDeployment
Returns a new instance of ArtifactDeployment.
254 255 256 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_alias ⇒ String
Output only. The artifact alias in the deployment spec, with Tag/SHA. e.g. us-
docker.pkg.dev/my-project/my-repo/image:1.0.0
Corresponds to the JSON property artifactAlias
218 219 220 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 218 def artifact_alias @artifact_alias end |
#artifact_reference ⇒ String
Output only. The artifact that is deployed.
Corresponds to the JSON property artifactReference
223 224 225 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 223 def artifact_reference @artifact_reference end |
#container_status_summary ⇒ String
Output only. The summary of container status of the artifact deployment.
Format as ContainerStatusState-Reason : restartCount e.g. "Waiting-
ImagePullBackOff : 3"
Corresponds to the JSON property containerStatusSummary
230 231 232 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 230 def container_status_summary @container_status_summary end |
#deploy_time ⇒ String
Output only. The time at which the deployment was deployed.
Corresponds to the JSON property deployTime
235 236 237 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 235 def deploy_time @deploy_time end |
#id ⇒ String
Output only. Unique identifier of ArtifactDeployment.
Corresponds to the JSON property id
240 241 242 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 240 def id @id end |
#source_commit_uris ⇒ Array<String>
Output only. The source commits at which this artifact was built. Extracted
from provenance.
Corresponds to the JSON property sourceCommitUris
246 247 248 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 246 def source_commit_uris @source_commit_uris end |
#undeploy_time ⇒ String
Output only. The time at which the deployment was undeployed, all artifacts
are considered undeployed once this time is set.
Corresponds to the JSON property undeployTime
252 253 254 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 252 def undeploy_time @undeploy_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
259 260 261 262 263 264 265 266 267 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 259 def update!(**args) @artifact_alias = args[:artifact_alias] if args.key?(:artifact_alias) @artifact_reference = args[:artifact_reference] if args.key?(:artifact_reference) @container_status_summary = args[:container_status_summary] if args.key?(:container_status_summary) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @id = args[:id] if args.key?(:id) @source_commit_uris = args[:source_commit_uris] if args.key?(:source_commit_uris) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) end |