Class: Google::Apis::DeveloperconnectV1::BitbucketDataCenterConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::BitbucketDataCenterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Configuration for connections to an instance of Bitbucket Data Center.
Instance Attribute Summary collapse
-
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.
-
#host_uri ⇒ String
Required.
-
#read_authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.
-
#server_version ⇒ String
Output only.
-
#service_directory_config ⇒ Google::Apis::DeveloperconnectV1::ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a connection.
-
#ssl_ca_certificate ⇒ String
Optional.
-
#webhook_secret_secret_version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BitbucketDataCenterConfig
constructor
A new instance of BitbucketDataCenterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BitbucketDataCenterConfig
Returns a new instance of BitbucketDataCenterConfig.
404 405 406 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and
associated metadata.
Corresponds to the JSON property authorizerCredential
365 366 367 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 365 def @authorizer_credential end |
#host_uri ⇒ String
Required. The URI of the Bitbucket Data Center host this connection is for.
Corresponds to the JSON property hostUri
370 371 372 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 370 def host_uri @host_uri end |
#read_authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and
associated metadata.
Corresponds to the JSON property readAuthorizerCredential
376 377 378 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 376 def @read_authorizer_credential end |
#server_version ⇒ String
Output only. Version of the Bitbucket Data Center server running on the
host_uri.
Corresponds to the JSON property serverVersion
382 383 384 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 382 def server_version @server_version end |
#service_directory_config ⇒ Google::Apis::DeveloperconnectV1::ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a
connection.
Corresponds to the JSON property serviceDirectoryConfig
388 389 390 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 388 def service_directory_config @service_directory_config end |
#ssl_ca_certificate ⇒ String
Optional. SSL certificate authority to trust when making requests to Bitbucket
Data Center.
Corresponds to the JSON property sslCaCertificate
394 395 396 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 394 def ssl_ca_certificate @ssl_ca_certificate end |
#webhook_secret_secret_version ⇒ String
Required. Immutable. SecretManager resource containing the webhook secret used
to verify webhook events, formatted as projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location). This is used to validate webhooks.
Corresponds to the JSON property webhookSecretSecretVersion
402 403 404 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 402 def webhook_secret_secret_version @webhook_secret_secret_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
409 410 411 412 413 414 415 416 417 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 409 def update!(**args) @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential) @host_uri = args[:host_uri] if args.key?(:host_uri) @read_authorizer_credential = args[:read_authorizer_credential] if args.key?(:read_authorizer_credential) @server_version = args[:server_version] if args.key?(:server_version) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate) @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version) end |