Class: Google::Apis::DeveloperconnectV1::CustomOAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Message for a customized OAuth config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomOAuthConfig

Returns a new instance of CustomOAuthConfig.



667
668
669
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_uriString

Required. Immutable. The OAuth2 authorization server URL. Corresponds to the JSON property authUri

Returns:

  • (String)


611
612
613
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 611

def auth_uri
  @auth_uri
end

#client_idString

Required. The client ID of the OAuth application. Corresponds to the JSON property clientId

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 616

def client_id
  @client_id
end

#client_secretString

Required. Input only. The client secret of the OAuth application. It will be provided as plain text, but encrypted and stored in developer connect. As INPUT_ONLY field, it will not be included in the output. Corresponds to the JSON property clientSecret

Returns:

  • (String)


623
624
625
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 623

def client_secret
  @client_secret
end

#host_uriString

Required. The host URI of the OAuth application. Corresponds to the JSON property hostUri

Returns:

  • (String)


628
629
630
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 628

def host_uri
  @host_uri
end

#pkce_disabledBoolean Also known as: pkce_disabled?

Optional. Disable PKCE for this OAuth config. PKCE is enabled by default. Corresponds to the JSON property pkceDisabled

Returns:

  • (Boolean)


633
634
635
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 633

def pkce_disabled
  @pkce_disabled
end

#scm_providerString

Required. The type of the SCM provider. Corresponds to the JSON property scmProvider

Returns:

  • (String)


639
640
641
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 639

def scm_provider
  @scm_provider
end

#scopesArray<String>

Required. The scopes to be requested during OAuth. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


644
645
646
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 644

def scopes
  @scopes
end

#server_versionString

Output only. SCM server version installed at the host URI. Corresponds to the JSON property serverVersion

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 649

def server_version
  @server_version
end

#service_directory_configGoogle::Apis::DeveloperconnectV1::ServiceDirectoryConfig

ServiceDirectoryConfig represents Service Directory configuration for a connection. Corresponds to the JSON property serviceDirectoryConfig



655
656
657
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 655

def service_directory_config
  @service_directory_config
end

#ssl_ca_certificateString

Optional. SSL certificate to use for requests to a private service. Corresponds to the JSON property sslCaCertificate

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 660

def ssl_ca_certificate
  @ssl_ca_certificate
end

#token_uriString

Required. Immutable. The OAuth2 token request URL. Corresponds to the JSON property tokenUri

Returns:

  • (String)


665
666
667
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 665

def token_uri
  @token_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 672

def update!(**args)
  @auth_uri = args[:auth_uri] if args.key?(:auth_uri)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @host_uri = args[:host_uri] if args.key?(:host_uri)
  @pkce_disabled = args[:pkce_disabled] if args.key?(:pkce_disabled)
  @scm_provider = args[:scm_provider] if args.key?(:scm_provider)
  @scopes = args[:scopes] if args.key?(:scopes)
  @server_version = args[:server_version] if args.key?(:server_version)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate)
  @token_uri = args[:token_uri] if args.key?(:token_uri)
end