Class: Google::Apis::DeveloperconnectV1::CustomOAuthConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::CustomOAuthConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Message for a customized OAuth config.
Instance Attribute Summary collapse
-
#auth_uri ⇒ String
Required.
-
#client_id ⇒ String
Required.
-
#client_secret ⇒ String
Required.
-
#host_uri ⇒ String
Required.
-
#pkce_disabled ⇒ Boolean
(also: #pkce_disabled?)
Optional.
-
#scm_provider ⇒ String
Required.
-
#scopes ⇒ Array<String>
Required.
-
#server_version ⇒ String
Output only.
-
#service_directory_config ⇒ Google::Apis::DeveloperconnectV1::ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a connection.
-
#ssl_ca_certificate ⇒ String
Optional.
-
#token_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomOAuthConfig
constructor
A new instance of CustomOAuthConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomOAuthConfig
Returns a new instance of CustomOAuthConfig.
667 668 669 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_uri ⇒ String
Required. Immutable. The OAuth2 authorization server URL.
Corresponds to the JSON property authUri
611 612 613 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 611 def auth_uri @auth_uri end |
#client_id ⇒ String
Required. The client ID of the OAuth application.
Corresponds to the JSON property clientId
616 617 618 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 616 def client_id @client_id end |
#client_secret ⇒ String
Required. Input only. The client secret of the OAuth application. It will be
provided as plain text, but encrypted and stored in developer connect. As
INPUT_ONLY field, it will not be included in the output.
Corresponds to the JSON property clientSecret
623 624 625 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 623 def client_secret @client_secret end |
#host_uri ⇒ String
Required. The host URI of the OAuth application.
Corresponds to the JSON property hostUri
628 629 630 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 628 def host_uri @host_uri end |
#pkce_disabled ⇒ Boolean Also known as: pkce_disabled?
Optional. Disable PKCE for this OAuth config. PKCE is enabled by default.
Corresponds to the JSON property pkceDisabled
633 634 635 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 633 def pkce_disabled @pkce_disabled end |
#scm_provider ⇒ String
Required. The type of the SCM provider.
Corresponds to the JSON property scmProvider
639 640 641 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 639 def scm_provider @scm_provider end |
#scopes ⇒ Array<String>
Required. The scopes to be requested during OAuth.
Corresponds to the JSON property scopes
644 645 646 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 644 def scopes @scopes end |
#server_version ⇒ String
Output only. SCM server version installed at the host URI.
Corresponds to the JSON property serverVersion
649 650 651 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 649 def server_version @server_version end |
#service_directory_config ⇒ Google::Apis::DeveloperconnectV1::ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a
connection.
Corresponds to the JSON property serviceDirectoryConfig
655 656 657 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 655 def service_directory_config @service_directory_config end |
#ssl_ca_certificate ⇒ String
Optional. SSL certificate to use for requests to a private service.
Corresponds to the JSON property sslCaCertificate
660 661 662 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 660 def ssl_ca_certificate @ssl_ca_certificate end |
#token_uri ⇒ String
Required. Immutable. The OAuth2 token request URL.
Corresponds to the JSON property tokenUri
665 666 667 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 665 def token_uri @token_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
672 673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 672 def update!(**args) @auth_uri = args[:auth_uri] if args.key?(:auth_uri) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @host_uri = args[:host_uri] if args.key?(:host_uri) @pkce_disabled = args[:pkce_disabled] if args.key?(:pkce_disabled) @scm_provider = args[:scm_provider] if args.key?(:scm_provider) @scopes = args[:scopes] if args.key?(:scopes) @server_version = args[:server_version] if args.key?(:server_version) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate) @token_uri = args[:token_uri] if args.key?(:token_uri) end |