Class: Google::Apis::DeveloperconnectV1::DeploymentEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

The DeploymentEvent resource represents the deployment of the artifact within the InsightsConfig resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentEvent

Returns a new instance of DeploymentEvent.



748
749
750
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_deploymentsArray<Google::Apis::DeveloperconnectV1::ArtifactDeployment>

Output only. The artifact deployments of the DeploymentEvent. Each artifact deployment contains the artifact uri and the runtime configuration uri. For GKE, this would be all the containers images that are deployed in the pod. Corresponds to the JSON property artifactDeployments



697
698
699
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 697

def artifact_deployments
  @artifact_deployments
end

#create_timeString

Output only. The create time of the DeploymentEvent. Corresponds to the JSON property createTime

Returns:

  • (String)


702
703
704
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 702

def create_time
  @create_time
end

#deploy_timeString

Output only. The time at which the DeploymentEvent was deployed. This would be the min of all ArtifactDeployment deploy_times. Corresponds to the JSON property deployTime

Returns:

  • (String)


708
709
710
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 708

def deploy_time
  @deploy_time
end

#nameString

Identifier. The name of the DeploymentEvent. This name is provided by Developer Connect insights. Format: projects/project/locations/location/ insightsConfigs/insights_config/deploymentEvents/uuid Corresponds to the JSON property name

Returns:

  • (String)


715
716
717
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 715

def name
  @name
end

#runtime_configGoogle::Apis::DeveloperconnectV1::RuntimeConfig

RuntimeConfig represents the runtimes where the application is deployed. Corresponds to the JSON property runtimeConfig



720
721
722
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 720

def runtime_config
  @runtime_config
end

#runtime_deployment_uriString

Output only. The runtime assigned URI of the DeploymentEvent. For GKE, this is the fully qualified replica set uri. e.g. container.googleapis.com/projects/ project/locations/location/clusters/cluster/k8s/namespaces/namespace/ apps/replicasets/replica-set-id For Cloud Run, this is the revision name. Corresponds to the JSON property runtimeDeploymentUri

Returns:

  • (String)


728
729
730
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 728

def runtime_deployment_uri
  @runtime_deployment_uri
end

#stateString

Output only. The state of the DeploymentEvent. Corresponds to the JSON property state

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 733

def state
  @state
end

#undeploy_timeString

Output only. The time at which the DeploymentEvent was undeployed, all artifacts are considered undeployed once this time is set. This would be the max of all ArtifactDeployment undeploy_times. If any ArtifactDeployment is still active (i.e. does not have an undeploy_time), this field will be empty. Corresponds to the JSON property undeployTime

Returns:

  • (String)


741
742
743
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 741

def undeploy_time
  @undeploy_time
end

#update_timeString

Output only. The update time of the DeploymentEvent. Corresponds to the JSON property updateTime

Returns:

  • (String)


746
747
748
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 746

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



753
754
755
756
757
758
759
760
761
762
763
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 753

def update!(**args)
  @artifact_deployments = args[:artifact_deployments] if args.key?(:artifact_deployments)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @name = args[:name] if args.key?(:name)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @runtime_deployment_uri = args[:runtime_deployment_uri] if args.key?(:runtime_deployment_uri)
  @state = args[:state] if args.key?(:state)
  @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end