Class: Google::Apis::DeveloperconnectV1::GitHubEnterpriseConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::GitHubEnterpriseConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Configuration for connections to an instance of GitHub Enterprise.
Instance Attribute Summary collapse
-
#app_id ⇒ Fixnum
Optional.
-
#app_installation_id ⇒ Fixnum
Optional.
-
#app_slug ⇒ String
Output only.
-
#host_uri ⇒ String
Required.
-
#installation_uri ⇒ String
Output only.
-
#organization ⇒ String
Optional.
-
#private_key_secret_version ⇒ String
Optional.
-
#server_version ⇒ String
Output only.
-
#service_directory_config ⇒ Google::Apis::DeveloperconnectV1::ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a connection.
-
#ssl_ca_certificate ⇒ String
Optional.
-
#webhook_secret_secret_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitHubEnterpriseConfig
constructor
A new instance of GitHubEnterpriseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitHubEnterpriseConfig
Returns a new instance of GitHubEnterpriseConfig.
1239 1240 1241 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ Fixnum
Optional. ID of the GitHub App created from the manifest.
Corresponds to the JSON property appId
1180 1181 1182 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1180 def app_id @app_id end |
#app_installation_id ⇒ Fixnum
Optional. ID of the installation of the GitHub App.
Corresponds to the JSON property appInstallationId
1185 1186 1187 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1185 def app_installation_id @app_installation_id end |
#app_slug ⇒ String
Output only. The URL-friendly name of the GitHub App.
Corresponds to the JSON property appSlug
1190 1191 1192 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1190 def app_slug @app_slug end |
#host_uri ⇒ String
Required. The URI of the GitHub Enterprise host this connection is for.
Corresponds to the JSON property hostUri
1195 1196 1197 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1195 def host_uri @host_uri end |
#installation_uri ⇒ String
Output only. The URI to navigate to in order to manage the installation
associated with this GitHubEnterpriseConfig.
Corresponds to the JSON property installationUri
1201 1202 1203 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1201 def installation_uri @installation_uri end |
#organization ⇒ String
Optional. Immutable. GitHub Enterprise organization in which the GitHub App is
created.
Corresponds to the JSON property organization
1207 1208 1209 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1207 def organization @organization end |
#private_key_secret_version ⇒ String
Optional. SecretManager resource containing the private key of the GitHub App,
formatted as projects/*/secrets/*/versions/* or projects/*/locations/*/
secrets/*/versions/* (if regional secrets are supported in that location).
Corresponds to the JSON property privateKeySecretVersion
1214 1215 1216 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1214 def private_key_secret_version @private_key_secret_version end |
#server_version ⇒ String
Output only. GitHub Enterprise version installed at the host_uri.
Corresponds to the JSON property serverVersion
1219 1220 1221 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1219 def server_version @server_version end |
#service_directory_config ⇒ Google::Apis::DeveloperconnectV1::ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a
connection.
Corresponds to the JSON property serviceDirectoryConfig
1225 1226 1227 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1225 def service_directory_config @service_directory_config end |
#ssl_ca_certificate ⇒ String
Optional. SSL certificate to use for requests to GitHub Enterprise.
Corresponds to the JSON property sslCaCertificate
1230 1231 1232 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1230 def ssl_ca_certificate @ssl_ca_certificate end |
#webhook_secret_secret_version ⇒ String
Optional. SecretManager resource containing the webhook secret of the GitHub
App, formatted as projects/*/secrets/*/versions/* or projects/*/locations/*/
secrets/*/versions/* (if regional secrets are supported in that location).
Corresponds to the JSON property webhookSecretSecretVersion
1237 1238 1239 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1237 def webhook_secret_secret_version @webhook_secret_secret_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1244 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_installation_id = args[:app_installation_id] if args.key?(:app_installation_id) @app_slug = args[:app_slug] if args.key?(:app_slug) @host_uri = args[:host_uri] if args.key?(:host_uri) @installation_uri = args[:installation_uri] if args.key?(:installation_uri) @organization = args[:organization] if args.key?(:organization) @private_key_secret_version = args[:private_key_secret_version] if args.key?(:private_key_secret_version) @server_version = args[:server_version] if args.key?(:server_version) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) @ssl_ca_certificate = args[:ssl_ca_certificate] if args.key?(:ssl_ca_certificate) @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version) end |