Class: Google::Apis::DeveloperconnectV1::GitLabConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::GitLabConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Configuration for connections to gitlab.com.
Instance Attribute Summary collapse
-
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.
-
#read_authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.
-
#webhook_secret_secret_version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitLabConfig
constructor
A new instance of GitLabConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitLabConfig
Returns a new instance of GitLabConfig.
1283 1284 1285 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and
associated metadata.
Corresponds to the JSON property authorizerCredential
1267 1268 1269 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1267 def @authorizer_credential end |
#read_authorizer_credential ⇒ Google::Apis::DeveloperconnectV1::UserCredential
Represents a personal access token that authorized the Connection, and
associated metadata.
Corresponds to the JSON property readAuthorizerCredential
1273 1274 1275 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1273 def @read_authorizer_credential end |
#webhook_secret_secret_version ⇒ String
Required. Immutable. SecretManager resource containing the webhook secret of a
GitLab project, formatted as projects/*/secrets/*/versions/* or projects/*/
locations/*/secrets/*/versions/* (if regional secrets are supported in that
location). This is used to validate webhooks.
Corresponds to the JSON property webhookSecretSecretVersion
1281 1282 1283 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1281 def webhook_secret_secret_version @webhook_secret_secret_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1288 1289 1290 1291 1292 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1288 def update!(**args) @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential) @read_authorizer_credential = args[:read_authorizer_credential] if args.key?(:read_authorizer_credential) @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version) end |