Class: Google::Apis::DeveloperconnectV1::GitProxyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

The git proxy configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitProxyConfig

Returns a new instance of GitProxyConfig.



1376
1377
1378
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Setting this to true allows the git proxy to be used for performing git operations on the repositories linked in the connection. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1365
1366
1367
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1365

def enabled
  @enabled
end

#http_proxy_base_uriString

Output only. The base URI for the HTTP proxy endpoint. Has the format https:// generatedID-c-h-shortRegion.developerconnect.dev Populated only when enabled is set to true. This endpoint is used by other Google services that integrate with Developer Connect. Corresponds to the JSON property httpProxyBaseUri

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1374

def http_proxy_base_uri
  @http_proxy_base_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1381
1382
1383
1384
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1381

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @http_proxy_base_uri = args[:http_proxy_base_uri] if args.key?(:http_proxy_base_uri)
end