Class: Google::Apis::DeveloperconnectV1::GitProxyConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::GitProxyConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
The git proxy configuration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#http_proxy_base_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitProxyConfig
constructor
A new instance of GitProxyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitProxyConfig
Returns a new instance of GitProxyConfig.
1376 1377 1378 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Setting this to true allows the git proxy to be used for performing
git operations on the repositories linked in the connection.
Corresponds to the JSON property enabled
1365 1366 1367 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1365 def enabled @enabled end |
#http_proxy_base_uri ⇒ String
Output only. The base URI for the HTTP proxy endpoint. Has the format https://
generatedID-c-h-shortRegion.developerconnect.dev Populated only when
enabled is set to true. This endpoint is used by other Google services that
integrate with Developer Connect.
Corresponds to the JSON property httpProxyBaseUri
1374 1375 1376 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1374 def http_proxy_base_uri @http_proxy_base_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1381 1382 1383 1384 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1381 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @http_proxy_base_uri = args[:http_proxy_base_uri] if args.key?(:http_proxy_base_uri) end |