Class: Google::Apis::DeveloperconnectV1::GitRepositoryLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

Message describing the GitRepositoryLink object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitRepositoryLink

Returns a new instance of GitRepositoryLink.



1457
1458
1459
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Allows clients to store small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1394
1395
1396
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1394

def annotations
  @annotations
end

#clone_uriString

Required. Git Clone URI. Corresponds to the JSON property cloneUri

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1399

def clone_uri
  @clone_uri
end

#create_timeString

Output only. [Output only] Create timestamp Corresponds to the JSON property createTime

Returns:

  • (String)


1404
1405
1406
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1404

def create_time
  @create_time
end

#delete_timeString

Output only. [Output only] Delete timestamp Corresponds to the JSON property deleteTime

Returns:

  • (String)


1409
1410
1411
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1409

def delete_time
  @delete_time
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1416
1417
1418
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1416

def etag
  @etag
end

#git_proxy_uriString

Output only. URI to access the linked repository through the Git Proxy. This field is only populated if the git proxy is enabled for the connection. Corresponds to the JSON property gitProxyUri

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1422

def git_proxy_uri
  @git_proxy_uri
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1427
1428
1429
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1427

def labels
  @labels
end

#nameString

Identifier. Resource name of the repository, in the format projects/*/ locations/*/connections/*/gitRepositoryLinks/*. Corresponds to the JSON property name

Returns:

  • (String)


1433
1434
1435
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1433

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. Set to true when the connection is being set up or updated in the background. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1439
1440
1441
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1439

def reconciling
  @reconciling
end

#uidString

Output only. A system-assigned unique identifier for the GitRepositoryLink. Corresponds to the JSON property uid

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1445

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update timestamp Corresponds to the JSON property updateTime

Returns:

  • (String)


1450
1451
1452
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1450

def update_time
  @update_time
end

#webhook_idString

Output only. External ID of the webhook created for the repository. Corresponds to the JSON property webhookId

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1455

def webhook_id
  @webhook_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1462

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @clone_uri = args[:clone_uri] if args.key?(:clone_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @etag = args[:etag] if args.key?(:etag)
  @git_proxy_uri = args[:git_proxy_uri] if args.key?(:git_proxy_uri)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @webhook_id = args[:webhook_id] if args.key?(:webhook_id)
end