Class: Google::Apis::DeveloperconnectV1::InsightsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

The InsightsConfig resource is the core configuration object to capture events from your Software Development Lifecycle. It acts as the central hub for managing how Developer Connect understands your application, its runtime environments, and the artifacts deployed within them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsightsConfig

Returns a new instance of InsightsConfig.



1668
1669
1670
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. User specified annotations. See https://google.aip.dev/148# annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1601
1602
1603
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1601

def annotations
  @annotations
end

#app_hub_applicationString

Optional. The name of the App Hub Application. Format: projects/project/ locations/location/applications/application Corresponds to the JSON property appHubApplication

Returns:

  • (String)


1607
1608
1609
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1607

def app_hub_application
  @app_hub_application
end

#artifact_configsArray<Google::Apis::DeveloperconnectV1::ArtifactConfig>

Optional. The artifact configurations of the artifacts that are deployed. Corresponds to the JSON property artifactConfigs



1612
1613
1614
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1612

def artifact_configs
  @artifact_configs
end

#create_timeString

Output only. Create timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1617
1618
1619
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1617

def create_time
  @create_time
end

#errorsArray<Google::Apis::DeveloperconnectV1::Status>

Output only. Any errors that occurred while setting up the InsightsConfig. Each error will be in the format: field_name: error_message, e.g. GetAppHubApplication: Permission denied while getting App Hub application. Please grant permissions to the P4SA. Corresponds to the JSON property errors



1625
1626
1627
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1625

def errors
  @errors
end

#labelsHash<String,String>

Optional. Set of labels associated with an InsightsConfig. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1630
1631
1632
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1630

def labels
  @labels
end

#nameString

Identifier. The name of the InsightsConfig. Format: projects/project/ locations/location/insightsConfigs/insightsConfig Corresponds to the JSON property name

Returns:

  • (String)


1636
1637
1638
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1636

def name
  @name
end

#projectsGoogle::Apis::DeveloperconnectV1::Projects

Projects represents the projects to track with the InsightsConfig. Corresponds to the JSON property projects



1641
1642
1643
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1641

def projects
  @projects
end

#reconcilingBoolean Also known as: reconciling?

Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to true if the current state of InsightsConfig does not match the user's intended state, and the service is actively updating the resource to reconcile them. This can happen due to user-triggered updates or system actions like failover or maintenance. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1650
1651
1652
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1650

def reconciling
  @reconciling
end

#runtime_configsArray<Google::Apis::DeveloperconnectV1::RuntimeConfig>

Output only. The runtime configurations where the application is deployed. Corresponds to the JSON property runtimeConfigs



1656
1657
1658
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1656

def runtime_configs
  @runtime_configs
end

#stateString

Optional. Output only. The state of the InsightsConfig. Corresponds to the JSON property state

Returns:

  • (String)


1661
1662
1663
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1661

def state
  @state
end

#update_timeString

Output only. Update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1666

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1673

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_hub_application = args[:app_hub_application] if args.key?(:app_hub_application)
  @artifact_configs = args[:artifact_configs] if args.key?(:artifact_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @errors = args[:errors] if args.key?(:errors)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @projects = args[:projects] if args.key?(:projects)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @runtime_configs = args[:runtime_configs] if args.key?(:runtime_configs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end