Class: Google::Apis::DeveloperconnectV1::InstallationState
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::InstallationState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Describes stage and necessary actions to be taken by the user to complete the installation. Used for GitHub and GitHub Enterprise based connections.
Instance Attribute Summary collapse
-
#action_uri ⇒ String
Output only.
-
#message ⇒ String
Output only.
-
#stage ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstallationState
constructor
A new instance of InstallationState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstallationState
Returns a new instance of InstallationState.
1742 1743 1744 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_uri ⇒ String
Output only. Link to follow for next action. Empty string if the installation
is already complete.
Corresponds to the JSON property actionUri
1729 1730 1731 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1729 def action_uri @action_uri end |
#message ⇒ String
Output only. Message of what the user should do next to continue the
installation. Empty string if the installation is already complete.
Corresponds to the JSON property message
1735 1736 1737 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1735 def @message end |
#stage ⇒ String
Output only. Current step of the installation process.
Corresponds to the JSON property stage
1740 1741 1742 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1740 def stage @stage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1747 1748 1749 1750 1751 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 1747 def update!(**args) @action_uri = args[:action_uri] if args.key?(:action_uri) @message = args[:message] if args.key?(:message) @stage = args[:stage] if args.key?(:stage) end |