Class: Google::Apis::DeveloperconnectV1::ProxyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

The proxy configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProxyConfig

Returns a new instance of ProxyConfig.



2447
2448
2449
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Setting this to true allows the git and http proxies to perform actions on behalf of the user configured under the account connector. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2436
2437
2438
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2436

def enabled
  @enabled
end

#http_proxy_base_uriString

Output only. The base URI for the HTTP proxy endpoint. Has the format https:// generatedID-a-h-shortRegion.developerconnect.dev Populated only when enabled is set to true. This endpoint is used by other Google services that integrate with Developer Connect. Corresponds to the JSON property httpProxyBaseUri

Returns:

  • (String)


2445
2446
2447
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2445

def http_proxy_base_uri
  @http_proxy_base_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2452
2453
2454
2455
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2452

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @http_proxy_base_uri = args[:http_proxy_base_uri] if args.key?(:http_proxy_base_uri)
end