Class: Google::Apis::DeveloperconnectV1::StartOAuthResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::StartOAuthResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
Message for responding to starting an OAuth flow.
Instance Attribute Summary collapse
-
#auth_uri ⇒ String
The authorization server URL to the OAuth flow of the service provider.
-
#client_id ⇒ String
The client ID to the OAuth App of the service provider.
-
#code_challenge ⇒ String
Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.1 Corresponds to the JSON property
codeChallenge. -
#code_challenge_method ⇒ String
Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.2 Corresponds to the JSON property
codeChallengeMethod. -
#scopes ⇒ Array<String>
The list of scopes requested by the application.
-
#system_provider_id ⇒ String
The ID of the system provider.
-
#ticket ⇒ String
The ticket to be used for post processing the callback from the service provider.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartOAuthResponse
constructor
A new instance of StartOAuthResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartOAuthResponse
Returns a new instance of StartOAuthResponse.
2589 2590 2591 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_uri ⇒ String
The authorization server URL to the OAuth flow of the service provider.
Corresponds to the JSON property authUri
2556 2557 2558 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2556 def auth_uri @auth_uri end |
#client_id ⇒ String
The client ID to the OAuth App of the service provider.
Corresponds to the JSON property clientId
2561 2562 2563 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2561 def client_id @client_id end |
#code_challenge ⇒ String
Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.1
Corresponds to the JSON property codeChallenge
2566 2567 2568 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2566 def code_challenge @code_challenge end |
#code_challenge_method ⇒ String
Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.2
Corresponds to the JSON property codeChallengeMethod
2571 2572 2573 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2571 def code_challenge_method @code_challenge_method end |
#scopes ⇒ Array<String>
The list of scopes requested by the application.
Corresponds to the JSON property scopes
2576 2577 2578 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2576 def scopes @scopes end |
#system_provider_id ⇒ String
The ID of the system provider.
Corresponds to the JSON property systemProviderId
2581 2582 2583 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2581 def system_provider_id @system_provider_id end |
#ticket ⇒ String
The ticket to be used for post processing the callback from the service
provider.
Corresponds to the JSON property ticket
2587 2588 2589 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2587 def ticket @ticket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2594 2595 2596 2597 2598 2599 2600 2601 2602 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2594 def update!(**args) @auth_uri = args[:auth_uri] if args.key?(:auth_uri) @client_id = args[:client_id] if args.key?(:client_id) @code_challenge = args[:code_challenge] if args.key?(:code_challenge) @code_challenge_method = args[:code_challenge_method] if args.key?(:code_challenge_method) @scopes = args[:scopes] if args.key?(:scopes) @system_provider_id = args[:system_provider_id] if args.key?(:system_provider_id) @ticket = args[:ticket] if args.key?(:ticket) end |