Class: Google::Apis::DeveloperconnectV1::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb

Overview

User represents a user connected to the service providers through a AccountConnector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



2671
2672
2673
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the user was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2652
2653
2654
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2652

def create_time
  @create_time
end

#display_nameString

Output only. Developer Connect automatically converts user identity to some human readable description, e.g., email address. Corresponds to the JSON property displayName

Returns:

  • (String)


2658
2659
2660
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2658

def display_name
  @display_name
end

#last_token_request_timeString

Output only. The timestamp when the token was last requested. Corresponds to the JSON property lastTokenRequestTime

Returns:

  • (String)


2663
2664
2665
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2663

def last_token_request_time
  @last_token_request_time
end

#nameString

Identifier. Resource name of the user, in the format projects/*/locations/*/ accountConnectors/*/users/*. Corresponds to the JSON property name

Returns:

  • (String)


2669
2670
2671
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2669

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2676
2677
2678
2679
2680
2681
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2676

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @last_token_request_time = args[:last_token_request_time] if args.key?(:last_token_request_time)
  @name = args[:name] if args.key?(:name)
end