Class: Google::Apis::DeveloperconnectV1::UserRepository
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperconnectV1::UserRepository
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerconnect_v1/classes.rb,
lib/google/apis/developerconnect_v1/representations.rb,
lib/google/apis/developerconnect_v1/representations.rb
Overview
A user repository that can be linked to the account connector. Consists of the repo name and the git proxy URL to forward requests to this repo.
Instance Attribute Summary collapse
-
#clone_uri ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#git_proxy_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserRepository
constructor
A new instance of UserRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserRepository
Returns a new instance of UserRepository.
2737 2738 2739 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clone_uri ⇒ String
Output only. The git clone URL of the repo. For example: https://github.com/
myuser/myrepo.git
Corresponds to the JSON property cloneUri
2722 2723 2724 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2722 def clone_uri @clone_uri end |
#display_name ⇒ String
Output only. The user friendly repo name (e.g., myuser/myrepo)
Corresponds to the JSON property displayName
2727 2728 2729 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2727 def display_name @display_name end |
#git_proxy_uri ⇒ String
Output only. The Git proxy URL for this repo. For example: https://us-west1-
git.developerconnect.dev/a/my-proj/my-ac/myuser/myrepo.git. Populated only
when proxy_config.enabled is set to true in the Account Connector. This
URL is used by other Google services that integrate with Developer Connect.
Corresponds to the JSON property gitProxyUri
2735 2736 2737 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2735 def git_proxy_uri @git_proxy_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2742 2743 2744 2745 2746 |
# File 'lib/google/apis/developerconnect_v1/classes.rb', line 2742 def update!(**args) @clone_uri = args[:clone_uri] if args.key?(:clone_uri) @display_name = args[:display_name] if args.key?(:display_name) @git_proxy_uri = args[:git_proxy_uri] if args.key?(:git_proxy_uri) end |